Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(560)

Unified Diff: components/offline_pages/core/prefetch/prefetch_dispatcher.h

Issue 2914703002: [Offline Prefetch] Backoff support for PrefetchBackgroundTask (Closed)
Patch Set: Fix trybots Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/core/prefetch/prefetch_dispatcher.h
diff --git a/components/offline_pages/core/prefetch/prefetch_dispatcher.h b/components/offline_pages/core/prefetch/prefetch_dispatcher.h
index 36f9b206de3b4931cd2951798012fbeac27d9977..5c147ed567aa10cf23f42db4e2bd17f5796ca578 100644
--- a/components/offline_pages/core/prefetch/prefetch_dispatcher.h
+++ b/components/offline_pages/core/prefetch/prefetch_dispatcher.h
@@ -39,9 +39,9 @@ class PrefetchDispatcher {
ScopedBackgroundTask() = default;
virtual ~ScopedBackgroundTask() = default;
- // Used on destruction to inform the system about whether rescheduling is
- // required.
- virtual void SetNeedsReschedule(bool reschedule) = 0;
+ // Used on destruction to inform the system about whether rescheduling with
+ // or without backoff is required.
+ virtual void SetNeedsReschedule(bool reschedule, bool backoff) = 0;
};
virtual ~PrefetchDispatcher() = default;
@@ -70,7 +70,7 @@ class PrefetchDispatcher {
// Called when a task must stop immediately due to system constraints. After
// this call completes, the system will reschedule the task based on whether
// SetNeedsReschedule has been called.
- virtual void StopBackgroundTask(ScopedBackgroundTask* task) = 0;
+ virtual void StopBackgroundTask(bool signaled_by_system) = 0;
dewittj 2017/05/31 21:33:33 Instead of signaled_by_system, can you please have
jianli 2017/06/01 00:09:59 Done.
};
} // namespace offline_pages

Powered by Google App Engine
This is Rietveld 408576698